@@ -86,24 +86,23 @@ public abstract class GeneratedMessageLite<
   @Override
   @SuppressWarnings("unchecked") // Guaranteed by runtime.
   public final Parser<MessageType> getParserForType() {
-    return (Parser<MessageType>) dynamicMethod(MethodToInvoke.GET_PARSER, null, null);
+    return (Parser<MessageType>) dynamicMethod(MethodToInvoke.GET_PARSER);
   }
 
   @Override
   @SuppressWarnings("unchecked") // Guaranteed by runtime.
   public final MessageType getDefaultInstanceForType() {
-    return (MessageType) dynamicMethod(MethodToInvoke.GET_DEFAULT_INSTANCE, null, null);
+    return (MessageType) dynamicMethod(MethodToInvoke.GET_DEFAULT_INSTANCE);
   }
 
   @Override
   @SuppressWarnings("unchecked") // Guaranteed by runtime.
   public final BuilderType newBuilderForType() {
-    return (BuilderType) dynamicMethod(MethodToInvoke.NEW_BUILDER, null, null);
+    return (BuilderType) dynamicMethod(MethodToInvoke.NEW_BUILDER);
   }
 
-  @SuppressWarnings("unchecked") // Guaranteed by runtime.
   MessageType newMutableInstance() {
-    return (MessageType) dynamicMethod(MethodToInvoke.NEW_MUTABLE_INSTANCE, null, null);
+    return (MessageType) dynamicMethod(MethodToInvoke.NEW_MUTABLE_INSTANCE);
   }
 
   /**
@@ -203,12 +202,11 @@ public abstract class GeneratedMessageLite<
     markImmutable();
   }
 
-  @SuppressWarnings("unchecked") // Guaranteed by runtime.
   protected final <
           MessageType extends GeneratedMessageLite<MessageType, BuilderType>,
           BuilderType extends GeneratedMessageLite.Builder<MessageType, BuilderType>>
       BuilderType createBuilder() {
-    return (BuilderType) dynamicMethod(MethodToInvoke.NEW_BUILDER, null, null);
+    return (BuilderType) dynamicMethod(MethodToInvoke.NEW_BUILDER);
   }
 
   protected final <
@@ -226,7 +224,7 @@ public abstract class GeneratedMessageLite<
   @Override
   @SuppressWarnings("unchecked")
   public final BuilderType toBuilder() {
-    BuilderType builder = (BuilderType) dynamicMethod(MethodToInvoke.NEW_BUILDER, null, null);
+    BuilderType builder = (BuilderType) dynamicMethod(MethodToInvoke.NEW_BUILDER);
     return builder.mergeFrom((MessageType) this);
   }
 
@@ -277,6 +275,19 @@ public abstract class GeneratedMessageLite<
           Object arg0,
           Object arg1);
 
+  /** Same as {@link #dynamicMethod(MethodToInvoke, Object, Object)} with {@code null} padding. */
+  @CanIgnoreReturnValue
+  protected Object dynamicMethod(
+      MethodToInvoke method,
+          Object arg0) {
+    return dynamicMethod(method, arg0, null);
+  }
+
+  /** Same as {@link #dynamicMethod(MethodToInvoke, Object, Object)} with {@code null} padding. */
+  protected Object dynamicMethod(MethodToInvoke method) {
+    return dynamicMethod(method, null, null);
+  }
+
   void clearMemoizedSerializedSize() {
     setMemoizedSerializedSize(UNINITIALIZED_SERIALIZED_SIZE);
   }
@@ -344,7 +355,7 @@ public abstract class GeneratedMessageLite<
 
   /** Constructs a {@link MessageInfo} for this message type. */
   Object buildMessageInfo() throws Exception {
-    return dynamicMethod(MethodToInvoke.BUILD_MESSAGE_INFO, null, null);
+    return dynamicMethod(MethodToInvoke.BUILD_MESSAGE_INFO);
   }
 
   private static Map<Class<?>, GeneratedMessageLite<?, ?>> defaultInstanceMap =
@@ -496,20 +507,24 @@ public abstract class GeneratedMessageLite<
       return (BuilderType) this;
     }
 
+    private static <MessageType> void mergeFromInstance(MessageType dest, MessageType src) {
+      Protobuf.getInstance().schemaFor(dest).mergeFrom(dest, src);
+    }
+
+    @Override
+    public MessageType getDefaultInstanceForType() {
+      return defaultInstance;
+    }
+
     @Override
     public BuilderType mergeFrom(
         byte[] input, int offset, int length, ExtensionRegistryLite extensionRegistry)
         throws InvalidProtocolBufferException {
       copyOnWrite();
       try {
-        Protobuf.getInstance()
-            .schemaFor(instance)
-            .mergeFrom(
-                instance,
-                input,
-                offset,
-                offset + length,
-                new ArrayDecoders.Registers(extensionRegistry));
+        Protobuf.getInstance().schemaFor(instance).mergeFrom(
+            instance, input, offset, offset + length,
+            new ArrayDecoders.Registers(extensionRegistry));
       } catch (InvalidProtocolBufferException e) {
         throw e;
       } catch (IndexOutOfBoundsException e) {
@@ -521,7 +536,8 @@ public abstract class GeneratedMessageLite<
     }
 
     @Override
-    public BuilderType mergeFrom(byte[] input, int offset, int length)
+    public BuilderType mergeFrom(
+        byte[] input, int offset, int length)
         throws InvalidProtocolBufferException {
       return mergeFrom(input, offset, length, ExtensionRegistryLite.getEmptyRegistry());
     }
@@ -535,9 +551,8 @@ public abstract class GeneratedMessageLite<
       try {
         // TODO: Try to make input with type CodedInputStream.ArrayDecoder use
         // fast path.
-        Protobuf.getInstance()
-            .schemaFor(instance)
-            .mergeFrom(instance, CodedInputStreamReader.forCodedInput(input), extensionRegistry);
+        Protobuf.getInstance().schemaFor(instance).mergeFrom(
+            instance, CodedInputStreamReader.forCodedInput(input), extensionRegistry);
       } catch (RuntimeException e) {
         if (e.getCause() instanceof IOException) {
           throw (IOException) e.getCause();
@@ -546,15 +561,6 @@ public abstract class GeneratedMessageLite<
       }
       return (BuilderType) this;
     }
-
-    private static <MessageType> void mergeFromInstance(MessageType dest, MessageType src) {
-      Protobuf.getInstance().schemaFor(dest).mergeFrom(dest, src);
-    }
-
-    @Override
-    public MessageType getDefaultInstanceForType() {
-      return defaultInstance;
-    }
   }
 
   // =================================================================
@@ -672,7 +678,7 @@ public abstract class GeneratedMessageLite<
           while (input.getBytesUntilLimit() > 0) {
             Object value =
                 FieldSet.readPrimitiveField(
-                    input, extension.descriptor.getLiteType(), /* checkUtf8= */ false);
+                    input, extension.descriptor.getLiteType(), /*checkUtf8=*/ false);
             extensions.addRepeatedField(extension.descriptor, value);
           }
         }
@@ -713,7 +719,7 @@ public abstract class GeneratedMessageLite<
           default:
             value =
                 FieldSet.readPrimitiveField(
-                    input, extension.descriptor.getLiteType(), /* checkUtf8= */ false);
+                    input, extension.descriptor.getLiteType(), /*checkUtf8=*/ false);
             break;
         }
 
@@ -1427,10 +1433,8 @@ public abstract class GeneratedMessageLite<
         java.lang.reflect.Field defaultInstanceField =
             messageClass.getDeclaredField("DEFAULT_INSTANCE");
         defaultInstanceField.setAccessible(true);
-        MessageLite.Builder builder =
-            ((MessageLite) defaultInstanceField.get(null)).newBuilderForType();
-        builder.mergeFrom(asBytes);
-        return builder.buildPartial();
+        MessageLite defaultInstance = (MessageLite) defaultInstanceField.get(null);
+        return defaultInstance.newBuilderForType().mergeFrom(asBytes).buildPartial();
       } catch (ClassNotFoundException e) {
         throw new RuntimeException("Unable to find proto buffer class: " + messageClassName, e);
       } catch (NoSuchFieldException e) {
@@ -1445,16 +1449,7 @@ public abstract class GeneratedMessageLite<
     }
 
     private Class<?> resolveMessageClass() throws ClassNotFoundException {
-      if (messageClass == null) {
-        Class<?> clazz =
-            Class.forName(
-                messageClassName, /* initialize= */ false, getClass().getClassLoader());
-        if (!MessageLite.class.isAssignableFrom(clazz)) {
-          throw new ClassNotFoundException();
-        }
-        return clazz;
-      }
-      return messageClass;
+      return messageClass != null ? messageClass : Class.forName(messageClassName);
     }
   }
 
@@ -1471,11 +1466,15 @@ public abstract class GeneratedMessageLite<
     return (GeneratedExtension<MessageType, T>) extension;
   }
 
-  /** A static helper method for checking if a message is initialized, optionally memoizing. */
-  private static final <T extends GeneratedMessageLite<T, ?>> boolean isInitialized(
+  /**
+   * A static helper method for checking if a message is initialized, optionally memoizing.
+   *
+   * <p>For use by generated code only.
+   */
+  protected static final <T extends GeneratedMessageLite<T, ?>> boolean isInitialized(
       T message, boolean shouldMemoize) {
     byte memoizedIsInitialized =
-        (Byte) message.dynamicMethod(MethodToInvoke.GET_MEMOIZED_IS_INITIALIZED, null, null);
+        (Byte) message.dynamicMethod(MethodToInvoke.GET_MEMOIZED_IS_INITIALIZED);
     if (memoizedIsInitialized == 1) {
       return true;
     }
@@ -1487,7 +1486,7 @@ public abstract class GeneratedMessageLite<
       // TODO: remove the unused variable
       Object unused =
           message.dynamicMethod(
-              MethodToInvoke.SET_MEMOIZED_IS_INITIALIZED, isInitialized ? message : null, null);
+              MethodToInvoke.SET_MEMOIZED_IS_INITIALIZED, isInitialized ? message : null);
     }
     return isInitialized;
   }
@@ -1714,9 +1713,8 @@ public abstract class GeneratedMessageLite<
   // Validates last tag.
   protected static <T extends GeneratedMessageLite<T, ?>> T parseFrom(
       T defaultInstance, byte[] data) throws InvalidProtocolBufferException {
-    return checkMessageInitialized(
-        parsePartialFrom(
-            defaultInstance, data, 0, data.length, ExtensionRegistryLite.getEmptyRegistry()));
+    return checkMessageInitialized(parsePartialFrom(
+        defaultInstance, data, 0, data.length, ExtensionRegistryLite.getEmptyRegistry()));
   }
 
   // Validates last tag.
