@@ -12,10 +12,8 @@
 #include "python/extension_dict.h"
 #include "python/map.h"
 #include "python/repeated.h"
-#include "upb/base/string_view.h"
 #include "upb/message/compare.h"
 #include "upb/message/copy.h"
-#include "upb/message/message.h"
 #include "upb/reflection/def.h"
 #include "upb/reflection/message.h"
 #include "upb/text/encode.h"
@@ -179,10 +177,8 @@ err:
 // The parent may also be non-present, in which case a mutation will trigger a
 // chain reaction.
 typedef struct PyUpb_Message {
-  // clang-format off
-  PyObject_HEAD
+  PyObject_HEAD;
   PyObject* arena;
-  // clang-format on
   uintptr_t def;  // Tagged, low bit 1 == upb_FieldDef*, else upb_MessageDef*
   union {
     // when def is msgdef, the data for this msg.
@@ -318,14 +314,9 @@ static bool PyUpb_Message_LookupName(PyUpb_Message* self, PyObject* py_name,
 static bool PyUpb_Message_InitMessageMapEntry(PyObject* dst, PyObject* src) {
   if (!src || !dst) return false;
 
-  if (PyDict_Check(src)) {
-    bool ok = PyUpb_Message_InitAttributes(dst, NULL, src) >= 0;
-    if (!ok) return false;
-  } else {
-    PyObject* ok = PyObject_CallMethod(dst, "CopyFrom", "O", src);
-    if (!ok) return false;
-    Py_DECREF(ok);
-  }
+  PyObject* ok = PyObject_CallMethod(dst, "CopyFrom", "O", src);
+  if (!ok) return false;
+  Py_DECREF(ok);
 
   return true;
 }
@@ -584,7 +575,9 @@ static bool PyUpb_Message_IsEmpty(const upb_Message* msg,
   upb_MessageValue val;
   if (upb_Message_Next(msg, m, ext_pool, &f, &val, &iter)) return false;
 
-  return !upb_Message_HasUnknown(msg);
+  size_t len;
+  (void)upb_Message_GetUnknown(msg, &len);
+  return len == 0;
 }
 
 static bool PyUpb_Message_IsEqual(PyUpb_Message* m1, PyObject* _m2) {
@@ -1110,6 +1103,7 @@ static PyObject* PyUpb_Message_Contains(PyObject* _self, PyObject* arg) {
       upb_Message* msg = PyUpb_Message_GetMsg(self);
       const upb_FieldDef* f = upb_MessageDef_FindFieldByName(msgdef, "fields");
       const upb_Map* map = upb_Message_GetFieldByDef(msg, f).map_val;
+      if (!map || upb_Map_Size(map) == 0) Py_RETURN_FALSE;
       const upb_MessageDef* entry_m = upb_FieldDef_MessageSubDef(f);
       const upb_FieldDef* key_f = upb_MessageDef_Field(entry_m, 0);
       upb_MessageValue u_key;
@@ -1489,8 +1483,7 @@ static PyObject* PyUpb_Message_DiscardUnknownFields(PyUpb_Message* self,
                                                     PyObject* arg) {
   PyUpb_Message_EnsureReified(self);
   const upb_MessageDef* msgdef = _PyUpb_Message_GetMsgdef(self);
-  const upb_DefPool* ext_pool = upb_FileDef_Pool(upb_MessageDef_File(msgdef));
-  upb_Message_DiscardUnknown(self->ptr.msg, msgdef, ext_pool, 64);
+  upb_Message_DiscardUnknown(self->ptr.msg, msgdef, 64);
   Py_RETURN_NONE;
 }
 
